from setuptools import setup

setup(
    name='mc_knight',
    version='0.0.5',
    author='魔扣少儿编程_Hugn',
    author_email='wang1183478375@outlook.com',
    url ='https://www.coding4fun.com.cn/',
    install_requires=['pygame>=1.9.4'
                      ],
    packages = ['Maps',
                'Resources/collision',
                'Resources',
                'Resources/sounds',
                'Resources/sprites',
                'Resources/sprites/background',
                'Resources/sprites/castle',
                'Resources/sprites/equipage',
                'Resources/sprites/grass',
                'Resources/sprites/pine',
                'Resources/sprites/Player',
                'Resources/sprites/stone',
                'Resources/sprites/stump',
                'Resources/sprites/water',
                'Script',
                'Script/assist',
                'Script/equipage',
                'Script/Layer',
                'Script/mcgame',
                'Script/Player',
                'Script/Render'],
    data_files=[('',['mc_knight.py']),
                ('Resources/sounds',['Resources/sounds/sound_0.mp3']),
                ('Resources/sprites/background',['Resources/sprites/background/bg_0.png',
                                                 'Resources/sprites/background/bg_1.png']),
                ('Resources/sprites/castle',['Resources/sprites/castle/castle_0.png']),
                ('Resources/sprites/equipage',['Resources/sprites/equipage/knight_full_15fps_1.png']),
                ('Resources/sprites/grass',['Resources/sprites/grass/grass_0.png',
                                            'Resources/sprites/grass/grass_1.png',
                                            'Resources/sprites/grass/grass_2.png',
                                            'Resources/sprites/grass/grass_3.png']),
                ('Resources/sprites/pine',['Resources/sprites/pine/pine_0.png',
                                           'Resources/sprites/pine/pine_1.png',
                                           'Resources/sprites/pine/pine_2.png',
                                           'Resources/sprites/pine/pine_3.png']),
                ('Resources/sprites/Player',['Resources/sprites/Player/knight_full_15fps_0.png']),
                ('Resources/sprites/stone',['Resources/sprites/stone/stone_0.png',
                                            'Resources/sprites/stone/stone_1.png']),
                ('Resources/sprites/stump',['Resources/sprites/stump/stump_0.png']),
                ('Resources/sprites/water',['Resources/sprites/water/water_0.png',
                                            'Resources/sprites/water/water_1.png',
                                            'Resources/sprites/water/water_2.png'])
                ],
    include_package_data = True, 
    zip_safe=False,
    )